"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Union

from typing_extensions import TypeAliasType

from .completionsstreamserverlessbodywithprompt import (
    CompletionsStreamServerlessBodyWithPrompt,
    CompletionsStreamServerlessBodyWithPromptTypedDict,
)
from .completionsstreamserverlessbodywithtokens import (
    CompletionsStreamServerlessBodyWithTokens,
    CompletionsStreamServerlessBodyWithTokensTypedDict,
)

ServerlessCompletionsStreamBodyTypedDict = TypeAliasType(
    "ServerlessCompletionsStreamBodyTypedDict",
    Union[
        CompletionsStreamServerlessBodyWithPromptTypedDict,
        CompletionsStreamServerlessBodyWithTokensTypedDict,
    ],
)


ServerlessCompletionsStreamBody = TypeAliasType(
    "ServerlessCompletionsStreamBody",
    Union[
        CompletionsStreamServerlessBodyWithPrompt,
        CompletionsStreamServerlessBodyWithTokens,
    ],
)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing_extensions import TypedDict

from friendli_core.types import BaseModel


class ContainerImageGenerateSuccessTypedDict(TypedDict):
    image: bytes
    r"""The base64-encoded image."""


class ContainerImageGenerateSuccess(BaseModel):
    image: bytes
    r"""The base64-encoded image."""



# Copyright (c) 2025-present, FriendliAI Inc. All rights reserved.

"""Friendli Python SDK."""

from __future__ import annotations

from friendli_core.sdk import AsyncFriendliCore, SyncFriendliCore

from ..config import Config
from ..platform.files import AsyncFiles, SyncFiles


class SyncPlatform:
    def __init__(self, core: SyncFriendliCore, config: Config):
        self._core = core
        self._config = config

        self.files = SyncFiles(core=self._core, config=self._config)


class AsyncPlatform:
    def __init__(self, core: AsyncFriendliCore, config: Config):
        self._core = core
        self._config = config

        self.files = AsyncFiles(core=self._core, config=self._config)



# Copyright (c) 2025-present, FriendliAI Inc. All rights reserved.

"""Friendli Python SDK."""

from __future__ import annotations

from typing import Any, Coroutine, Mapping, Optional

from friendli_core import models, utils
from friendli_core.sdk import AsyncFriendliCore, SyncFriendliCore
from friendli_core.types import UNSET, OptionalNullable

from ..config import Config


class SyncImage:
    def __init__(self, core: SyncFriendliCore, config: Config):
        self._core = core
        self._config = config

    def generate(
        self,
        *,
        model: str,
        num_inference_steps: int,
        prompt: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        guidance_scale: OptionalNullable[float] = UNSET,
        response_format: OptionalNullable[
            models.DedicatedImageGenerationBodyResponseFormat
        ] = "url",
        seed: OptionalNullable[int] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DedicatedImageGenerateSuccess:
        """Image generations

        Given a description, the model generates image(s).

        :param model: ID of target endpoint. If you want to send request to specific adapter, use the format \\"YOUR_ENDPOINT_ID:YOUR_ADAPTER_ROUTE\\". Otherwise, you can just use \\"YOUR_ENDPOINT_ID\\" alone.
        :param num_inference_steps: The number of inference steps to use during image generation. Supported range: [1, 50].
        :param prompt: A text description of the desired image(s).
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param guidance_scale: Adjusts the alignment of the generated image with the input prompt. Higher values (e.g., 8-10) make the output more faithful to the prompt, while lower values (e.g., 1-5) encourage more creative freedom. This parameter may be irrelevant for certain models, such as `FLUX.Schnell`.
        :param response_format: The format in which the generated image(s) will be returned. One of `url(default)`, `raw`, `png`, `jpeg`, and `jpg`.
        :param seed: The seed to use for image generation.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return self._core.dedicated.image.generate(
            model=model,
            num_inference_steps=num_inference_steps,
            prompt=prompt,
            x_friendli_team=x_friendli_team,
            guidance_scale=guidance_scale,
            response_format=response_format,
            seed=seed,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )


class AsyncImage:
    def __init__(self, core: AsyncFriendliCore, config: Config):
        self._core = core
        self._config = config

    async def generate(
        self,
        *,
        model: str,
        num_inference_steps: int,
        prompt: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        guidance_scale: OptionalNullable[float] = UNSET,
        response_format: OptionalNullable[
            models.DedicatedImageGenerationBodyResponseFormat
        ] = "url",
        seed: OptionalNullable[int] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DedicatedImageGenerateSuccess:
        """Image generations

        Given a description, the model generates image(s).

        :param model: ID of target endpoint. If you want to send request to specific adapter, use the format \\"YOUR_ENDPOINT_ID:YOUR_ADAPTER_ROUTE\\". Otherwise, you can just use \\"YOUR_ENDPOINT_ID\\" alone.
        :param num_inference_steps: The number of inference steps to use during image generation. Supported range: [1, 50].
        :param prompt: A text description of the desired image(s).
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param guidance_scale: Adjusts the alignment of the generated image with the input prompt. Higher values (e.g., 8-10) make the output more faithful to the prompt, while lower values (e.g., 1-5) encourage more creative freedom. This parameter may be irrelevant for certain models, such as `FLUX.Schnell`.
        :param response_format: The format in which the generated image(s) will be returned. One of `url(default)`, `raw`, `png`, `jpeg`, and `jpg`.
        :param seed: The seed to use for image generation.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return await self._core.dedicated.image.generate(
            model=model,
            prompt=prompt,
            x_friendli_team=x_friendli_team,
            num_inference_steps=num_inference_steps,
            response_format=response_format,
            seed=seed,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

import pydantic
from pydantic import model_serializer
from typing_extensions import Annotated, NotRequired, TypedDict

from friendli_core.types import (
    UNSET,
    UNSET_SENTINEL,
    BaseModel,
    Nullable,
    OptionalNullable,
)

from .autoscalingpolicy import AutoscalingPolicy, AutoscalingPolicyTypedDict
from .endpointadvancedconfig import (
    EndpointAdvancedConfig,
    EndpointAdvancedConfigTypedDict,
)
from .endpointsimplescaleconfig import (
    EndpointSimplescaleConfig,
    EndpointSimplescaleConfigTypedDict,
)


class DedicatedEndpointCreateBodyTypedDict(TypedDict):
    r"""Dedicated endpoint create request."""

    advanced: EndpointAdvancedConfigTypedDict
    r"""Endpoint advanced config."""
    hf_model_repo: str
    r"""HF ID of the model."""
    instance_option_id: str
    r"""The ID of the instance option."""
    name: str
    r"""The name of the endpoint."""
    project_id: str
    r"""The ID of the project that owns the endpoint."""
    autoscaling_policy: NotRequired[Nullable[AutoscalingPolicyTypedDict]]
    r"""The auto scaling configuration of the endpoint."""
    hf_model_repo_revision: NotRequired[Nullable[str]]
    r"""HF commit hash of the model."""
    initial_version_comment: NotRequired[Nullable[str]]
    r"""The comment for the initial version."""
    simplescale: NotRequired[Nullable[EndpointSimplescaleConfigTypedDict]]
    r"""The simple scaling configuration of the endpoint."""


class DedicatedEndpointCreateBody(BaseModel):
    r"""Dedicated endpoint create request."""

    advanced: EndpointAdvancedConfig
    r"""Endpoint advanced config."""

    hf_model_repo: Annotated[str, pydantic.Field(alias="hfModelRepo")]
    r"""HF ID of the model."""

    instance_option_id: Annotated[str, pydantic.Field(alias="instanceOptionId")]
    r"""The ID of the instance option."""

    name: str
    r"""The name of the endpoint."""

    project_id: Annotated[str, pydantic.Field(alias="projectId")]
    r"""The ID of the project that owns the endpoint."""

    autoscaling_policy: Annotated[
        OptionalNullable[AutoscalingPolicy], pydantic.Field(alias="autoscalingPolicy")
    ] = UNSET
    r"""The auto scaling configuration of the endpoint."""

    hf_model_repo_revision: Annotated[
        OptionalNullable[str], pydantic.Field(alias="hfModelRepoRevision")
    ] = UNSET
    r"""HF commit hash of the model."""

    initial_version_comment: Annotated[
        OptionalNullable[str], pydantic.Field(alias="initialVersionComment")
    ] = UNSET
    r"""The comment for the initial version."""

    simplescale: OptionalNullable[EndpointSimplescaleConfig] = UNSET
    r"""The simple scaling configuration of the endpoint."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "autoscalingPolicy",
            "hfModelRepoRevision",
            "initialVersionComment",
            "simplescale",
        ]
        nullable_fields = [
            "autoscalingPolicy",
            "hfModelRepoRevision",
            "initialVersionComment",
            "simplescale",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

InferenceDeploymentStatus = Literal[
    "UNKNOWN",
    "INITIALIZING",
    "RUNNING",
    "UPDATING",
    "SLEEPING",
    "AWAKING",
    "FAILED",
    "STOPPING",
    "TERMINATING",
    "TERMINATED",
    "READY",
]
r"""Status of inference deployment."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import weakref
from abc import abstractmethod
from typing import Any, Callable, Dict, Optional, Union, cast

import httpx

from friendli_core import models, utils
from friendli_core._hooks import SDKHooks
from friendli_core.container import AsyncContainer, SyncContainer
from friendli_core.dedicated import AsyncDedicated, SyncDedicated
from friendli_core.platform import AsyncPlatform, SyncPlatform
from friendli_core.serverless import AsyncServerless, SyncServerless
from friendli_core.types import UNSET, OptionalNullable

from .basesdk import AsyncSDK, BaseSDK, SyncSDK
from .httpclient import AsyncHttpClient, ClientOwner, HttpClient, close_clients
from .sdkconfiguration import SDKConfiguration
from .utils.logger import Logger, get_default_logger
from .utils.retries import RetryConfig


class BaseFriendliCore(BaseSDK):
    """Friendli Suite API Reference: This is an OpenAPI reference of Friendli Suite API."""

    def __init__(
        self,
        token: Optional[Union[Optional[str], Callable[[], Optional[str]]]] = None,
        server_idx: Optional[int] = None,
        server_url: Optional[str] = None,
        url_params: Optional[Dict[str, str]] = None,
        client: Optional[HttpClient] = None,
        async_client: Optional[AsyncHttpClient] = None,
        retry_config: OptionalNullable[RetryConfig] = UNSET,
        timeout_ms: Optional[int] = None,
        debug_logger: Optional[Logger] = None,
    ) -> None:
        """Instantiates the SDK configuring it with the provided parameters.

        :param token: The token required for authentication
        :param server_idx: The index of the server to use for all methods
        :param server_url: The server URL to use for all methods
        :param url_params: Parameters to optionally template the server URL with
        :param client: The HTTP client to use for all synchronous methods
        :param async_client: The Async HTTP client to use for all asynchronous methods
        :param retry_config: The retry configuration to use for all supported methods
        :param timeout_ms: Optional request timeout applied to each operation in milliseconds
        """
        client_supplied = True
        if client is None:
            client = httpx.Client()
            client_supplied = False
        assert issubclass(type(client), HttpClient), (
            "The provided client must implement the HttpClient protocol."
        )
        async_client_supplied = True
        if async_client is None:
            async_client = httpx.AsyncClient()
            async_client_supplied = False
        if debug_logger is None:
            debug_logger = get_default_logger()
        assert issubclass(type(async_client), AsyncHttpClient), (
            "The provided async_client must implement the AsyncHttpClient protocol."
        )
        security: Any = None
        if callable(token):
            security = lambda: models.Security(token=token())
        else:
            security = models.Security(token=token)
        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)
        BaseSDK.__init__(
            self,
            SDKConfiguration(
                client=client,
                client_supplied=client_supplied,
                async_client=async_client,
                async_client_supplied=async_client_supplied,
                security=security,
                server_url=server_url,
                server_idx=server_idx,
                retry_config=retry_config,
                timeout_ms=timeout_ms,
                debug_logger=debug_logger,
            ),
        )
        hooks = SDKHooks()
        current_server_url, *_ = self.sdk_configuration.get_server_details()
        server_url, self.sdk_configuration.client = hooks.sdk_init(
            current_server_url, client
        )
        if current_server_url != server_url:
            self.sdk_configuration.server_url = server_url
        self.sdk_configuration.__dict__["_hooks"] = hooks
        weakref.finalize(
            self,
            close_clients,
            cast(ClientOwner, self.sdk_configuration),
            self.sdk_configuration.client,
            self.sdk_configuration.client_supplied,
            self.sdk_configuration.async_client,
            self.sdk_configuration.async_client_supplied,
        )
        self._init_sdks()

    @abstractmethod
    def _init_sdks(self):
        pass


class SyncFriendliCore(BaseFriendliCore, SyncSDK):
    serverless: SyncServerless
    dedicated: SyncDedicated
    container: SyncContainer
    platform: SyncPlatform

    def _init_sdks(self):
        self.serverless = SyncServerless(self.sdk_configuration)
        self.dedicated = SyncDedicated(self.sdk_configuration)
        self.container = SyncContainer(self.sdk_configuration)
        self.platform = SyncPlatform(self.sdk_configuration)

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        if self.sdk_configuration.client is not None and (
            not self.sdk_configuration.client_supplied
        ):
            self.sdk_configuration.client.close()
        self.sdk_configuration.client = None


class AsyncFriendliCore(BaseFriendliCore, AsyncSDK):
    serverless: AsyncServerless
    dedicated: AsyncDedicated
    container: AsyncContainer
    platform: AsyncPlatform

    def _init_sdks(self):
        self.serverless = AsyncServerless(self.sdk_configuration)
        self.dedicated = AsyncDedicated(self.sdk_configuration)
        self.container = AsyncContainer(self.sdk_configuration)
        self.platform = AsyncPlatform(self.sdk_configuration)

    async def __aenter__(self):
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        if self.sdk_configuration.async_client is not None and (
            not self.sdk_configuration.async_client_supplied
        ):
            await self.sdk_configuration.async_client.aclose()
        self.sdk_configuration.async_client = None



# Copyright (c) 2025-present, FriendliAI Inc. All rights reserved.

"""Friendli Python SDK."""

from __future__ import annotations

from friendli_core.sdk import AsyncFriendliCore, SyncFriendliCore

from ..config import Config
from .chat import AsyncChat, SyncChat
from .completions import AsyncCompletions, SyncCompletions
from .endpoint import AsyncEndpoint, SyncEndpoint
from .image import AsyncImage, SyncImage
from .token import AsyncToken, SyncToken


class SyncDedicated:
    def __init__(self, core: SyncFriendliCore, config: Config):
        self._core = core
        self._config = config

        self.chat = SyncChat(core=self._core, config=self._config)
        self.completions = SyncCompletions(core=self._core, config=self._config)
        self.token = SyncToken(core=self._core, config=self._config)
        self.image = SyncImage(core=self._core, config=self._config)
        self.endpoint = SyncEndpoint(core=self._core, config=self._config)


class AsyncDedicated:
    def __init__(self, core: AsyncFriendliCore, config: Config):
        self._core = core
        self._config = config

        self.chat = AsyncChat(core=self._core, config=self._config)
        self.completions = AsyncCompletions(core=self._core, config=self._config)
        self.token = AsyncToken(core=self._core, config=self._config)
        self.image = AsyncImage(core=self._core, config=self._config)
        self.endpoint = AsyncEndpoint(core=self._core, config=self._config)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

import pydantic
from pydantic import model_serializer
from typing_extensions import Annotated, NotRequired, TypedDict

from friendli_core.types import (
    UNSET,
    UNSET_SENTINEL,
    BaseModel,
    Nullable,
    OptionalNullable,
)


class DedicatedEndpointSpecTypedDict(TypedDict):
    r"""Dedicated endpoint specification."""

    autoscaling_cooldown: int
    r"""The cooldown period in seconds between scaling operations."""
    autoscaling_max: int
    r"""The maximum number of replicas allowed."""
    autoscaling_min: int
    r"""The minimum number of replicas to maintain."""
    autoscaling_scalein_factor: float
    r"""The factor to scale in replicas by."""
    autoscaling_scaleout_factor: float
    r"""The factor to scale out replicas by."""
    creator_id: str
    r"""The ID of the user who created the endpoint."""
    curr_replica_cnt: int
    r"""The current number of replicas."""
    desired_replica_cnt: int
    r"""The desired number of replicas."""
    gpu_type: str
    r"""The type of GPU to use for the endpoint."""
    max_batch_size: int
    r"""The maximum batch size for inference requests."""
    name: str
    r"""The name of the endpoint."""
    num_gpu: int
    r"""The number of GPUs to use per replica."""
    project_id: str
    r"""The ID of the project that owns the endpoint."""
    team_id: str
    r"""The ID of the team that owns the endpoint."""
    tokenizer_add_special_tokens: bool
    r"""Whether to add special tokens in tokenizer input."""
    tokenizer_skip_special_tokens: bool
    r"""Whether to skip special tokens in tokenizer output."""
    updated_replica_cnt: int
    r"""The updated number of replicas."""
    idempotency_key: NotRequired[Nullable[str]]
    r"""The idempotency key of the endpoint."""
    instance_id: NotRequired[Nullable[str]]
    r"""The ID of the instance."""
    max_input_length: NotRequired[Nullable[int]]
    r"""The maximum allowed input length."""
    vm_region: NotRequired[Nullable[str]]
    r"""The region where the VM is deployed."""


class DedicatedEndpointSpec(BaseModel):
    r"""Dedicated endpoint specification."""

    autoscaling_cooldown: Annotated[int, pydantic.Field(alias="autoscalingCooldown")]
    r"""The cooldown period in seconds between scaling operations."""

    autoscaling_max: Annotated[int, pydantic.Field(alias="autoscalingMax")]
    r"""The maximum number of replicas allowed."""

    autoscaling_min: Annotated[int, pydantic.Field(alias="autoscalingMin")]
    r"""The minimum number of replicas to maintain."""

    autoscaling_scalein_factor: Annotated[
        float, pydantic.Field(alias="autoscalingScaleinFactor")
    ]
    r"""The factor to scale in replicas by."""

    autoscaling_scaleout_factor: Annotated[
        float, pydantic.Field(alias="autoscalingScaleoutFactor")
    ]
    r"""The factor to scale out replicas by."""

    creator_id: Annotated[str, pydantic.Field(alias="creatorId")]
    r"""The ID of the user who created the endpoint."""

    curr_replica_cnt: Annotated[int, pydantic.Field(alias="currReplicaCnt")]
    r"""The current number of replicas."""

    desired_replica_cnt: Annotated[int, pydantic.Field(alias="desiredReplicaCnt")]
    r"""The desired number of replicas."""

    gpu_type: Annotated[str, pydantic.Field(alias="gpuType")]
    r"""The type of GPU to use for the endpoint."""

    max_batch_size: Annotated[int, pydantic.Field(alias="maxBatchSize")]
    r"""The maximum batch size for inference requests."""

    name: str
    r"""The name of the endpoint."""

    num_gpu: Annotated[int, pydantic.Field(alias="numGpu")]
    r"""The number of GPUs to use per replica."""

    project_id: Annotated[str, pydantic.Field(alias="projectId")]
    r"""The ID of the project that owns the endpoint."""

    team_id: Annotated[str, pydantic.Field(alias="teamId")]
    r"""The ID of the team that owns the endpoint."""

    tokenizer_add_special_tokens: Annotated[
        bool, pydantic.Field(alias="tokenizerAddSpecialTokens")
    ]
    r"""Whether to add special tokens in tokenizer input."""

    tokenizer_skip_special_tokens: Annotated[
        bool, pydantic.Field(alias="tokenizerSkipSpecialTokens")
    ]
    r"""Whether to skip special tokens in tokenizer output."""

    updated_replica_cnt: Annotated[int, pydantic.Field(alias="updatedReplicaCnt")]
    r"""The updated number of replicas."""

    idempotency_key: Annotated[
        OptionalNullable[str], pydantic.Field(alias="idempotencyKey")
    ] = UNSET
    r"""The idempotency key of the endpoint."""

    instance_id: Annotated[
        OptionalNullable[str], pydantic.Field(alias="instanceId")
    ] = UNSET
    r"""The ID of the instance."""

    max_input_length: Annotated[
        OptionalNullable[int], pydantic.Field(alias="maxInputLength")
    ] = UNSET
    r"""The maximum allowed input length."""

    vm_region: Annotated[OptionalNullable[str], pydantic.Field(alias="vmRegion")] = (
        UNSET
    )
    r"""The region where the VM is deployed."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["idempotencyKey", "instanceId", "maxInputLength", "vmRegion"]
        nullable_fields = ["idempotencyKey", "instanceId", "maxInputLength", "vmRegion"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



# Copyright (c) 2025-present, FriendliAI Inc. All rights reserved.

"""Friendli Python SDK."""

from __future__ import annotations

import pydantic
from typing_extensions import Annotated

from friendli_core.types import UNSET, BaseModel, OptionalNullable
from friendli_core.utils import FieldMetadata, HeaderMetadata


class Config(BaseModel):
    x_friendli_team: Annotated[
        OptionalNullable[str],
        pydantic.Field(alias="X-Friendli-Team"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = UNSET



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

import pydantic
from pydantic.functional_validators import AfterValidator
from typing_extensions import Annotated, TypedDict

from friendli_core.types import BaseModel
from friendli_core.utils import validate_const

PlatformFilesRetrieveResultPurpose = Literal["batch", "model"]
r"""The intended purpose of the uploaded file. One of `batch` or `model`."""


class PlatformFilesRetrieveResultTypedDict(TypedDict):
    bytes_: int
    r"""The size of the file in bytes."""
    created: int
    r"""The Unix timestamp (in seconds) for when the file was created."""
    expires: int
    r"""The Unix timestamp (in seconds) for when the file will expire."""
    filename: str
    r"""The name of the file."""
    id: str
    r"""The ID of uploaded file."""
    purpose: PlatformFilesRetrieveResultPurpose
    r"""The intended purpose of the uploaded file. One of `batch` or `model`."""
    object: Literal["file"]
    r"""The object type, which is always `file`."""


class PlatformFilesRetrieveResult(BaseModel):
    bytes_: Annotated[int, pydantic.Field(alias="bytes")]
    r"""The size of the file in bytes."""

    created: int
    r"""The Unix timestamp (in seconds) for when the file was created."""

    expires: int
    r"""The Unix timestamp (in seconds) for when the file will expire."""

    filename: str
    r"""The name of the file."""

    id: str
    r"""The ID of uploaded file."""

    purpose: PlatformFilesRetrieveResultPurpose
    r"""The intended purpose of the uploaded file. One of `batch` or `model`."""

    OBJECT: Annotated[
        Annotated[Literal["file"], AfterValidator(validate_const("file"))],
        pydantic.Field(alias="object"),
    ] = "file"
    r"""The object type, which is always `file`."""



# Copyright (c) 2025-present, FriendliAI Inc. All rights reserved.

"""Friendli Python SDK."""

from __future__ import annotations

from typing import Any, Coroutine, List, Mapping, Optional

from friendli_core import models, utils
from friendli_core.sdk import AsyncFriendliCore, SyncFriendliCore
from friendli_core.types import UNSET, OptionalNullable

from ..config import Config


class SyncKnowledge:
    def __init__(self, core: SyncFriendliCore, config: Config):
        self._core = core
        self._config = config

    def retrieve(
        self,
        *,
        k: int,
        knowledge_ids: List[str],
        query: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ServerlessKnowledgeRetrievalSuccess:
        """Retrieve contexts from chosen knowledge base

        Retrieve related documents from knowledge base by similarity.

        :param k: Maximum number of top-ranked knowledge-base entries to return in results.
        :param knowledge_ids: A List of knowledge-base IDs. For now, only one knowledge-base is supported.
        :param query: A text string used to find relevant information within the knowledge-base.
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return self._core.serverless.knowledge.retrieve(
            k=k,
            knowledge_ids=knowledge_ids,
            query=query,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )


class AsyncKnowledge:
    def __init__(self, core: AsyncFriendliCore, config: Config):
        self._core = core
        self._config = config

    async def retrieve(
        self,
        *,
        k: int,
        knowledge_ids: List[str],
        query: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ServerlessKnowledgeRetrievalSuccess:
        """Retrieve contexts from chosen knowledge base

        Retrieve related documents from knowledge base by similarity.

        :param k: Maximum number of top-ranked knowledge-base entries to return in results.
        :param knowledge_ids: A List of knowledge-base IDs. For now, only one knowledge-base is supported.
        :param query: A text string used to find relevant information within the knowledge-base.
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return await self._core.serverless.knowledge.retrieve(
            k=k,
            knowledge_ids=knowledge_ids,
            query=query,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Union

from typing_extensions import TypeAliasType

from .completionsdedicatedbodywithprompt import (
    CompletionsDedicatedBodyWithPrompt,
    CompletionsDedicatedBodyWithPromptTypedDict,
)
from .completionsdedicatedbodywithtokens import (
    CompletionsDedicatedBodyWithTokens,
    CompletionsDedicatedBodyWithTokensTypedDict,
)

DedicatedCompletionsBodyTypedDict = TypeAliasType(
    "DedicatedCompletionsBodyTypedDict",
    Union[
        CompletionsDedicatedBodyWithPromptTypedDict,
        CompletionsDedicatedBodyWithTokensTypedDict,
    ],
)


DedicatedCompletionsBody = TypeAliasType(
    "DedicatedCompletionsBody",
    Union[CompletionsDedicatedBodyWithPrompt, CompletionsDedicatedBodyWithTokens],
)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from abc import abstractmethod

from friendli_core.endpoint import AsyncEndpoint, SyncEndpoint
from friendli_core.friendlicore_chat import AsyncFriendliCoreChat, SyncFriendliCoreChat
from friendli_core.friendlicore_completions import (
    AsyncFriendliCoreCompletions,
    SyncFriendliCoreCompletions,
)
from friendli_core.friendlicore_token import (
    AsyncFriendliCoreToken,
    SyncFriendliCoreToken,
)
from friendli_core.image import AsyncImage, SyncImage

from .basesdk import AsyncSDK, BaseSDK, SyncSDK
from .sdkconfiguration import SDKConfiguration


class BaseDedicated(BaseSDK):
    def __init__(self, sdk_config: SDKConfiguration) -> None:
        BaseSDK.__init__(self, sdk_config)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    @abstractmethod
    def _init_sdks(self):
        pass


class SyncDedicated(BaseDedicated, SyncSDK):
    chat: SyncFriendliCoreChat
    completions: SyncFriendliCoreCompletions
    token: SyncFriendliCoreToken
    image: SyncImage
    endpoint: SyncEndpoint

    def _init_sdks(self):
        self.chat = SyncFriendliCoreChat(self.sdk_configuration)
        self.completions = SyncFriendliCoreCompletions(self.sdk_configuration)
        self.token = SyncFriendliCoreToken(self.sdk_configuration)
        self.image = SyncImage(self.sdk_configuration)
        self.endpoint = SyncEndpoint(self.sdk_configuration)


class AsyncDedicated(BaseDedicated, AsyncSDK):
    chat: AsyncFriendliCoreChat
    completions: AsyncFriendliCoreCompletions
    token: AsyncFriendliCoreToken
    image: AsyncImage
    endpoint: AsyncEndpoint

    def _init_sdks(self):
        self.chat = AsyncFriendliCoreChat(self.sdk_configuration)
        self.completions = AsyncFriendliCoreCompletions(self.sdk_configuration)
        self.token = AsyncFriendliCoreToken(self.sdk_configuration)
        self.image = AsyncImage(self.sdk_configuration)
        self.endpoint = AsyncEndpoint(self.sdk_configuration)



# Copyright (c) 2025-present, FriendliAI Inc. All rights reserved.

"""Friendli Python SDK."""

from __future__ import annotations

from typing import Callable, Dict, Optional, Union

from friendli_core.httpclient import AsyncHttpClient, HttpClient
from friendli_core.sdk import AsyncFriendliCore, SyncFriendliCore
from friendli_core.types import UNSET, OptionalNullable
from friendli_core.utils.logger import Logger
from friendli_core.utils.retries import RetryConfig

from .config import Config
from .container import AsyncContainer, SyncContainer
from .dedicated import AsyncDedicated, SyncDedicated
from .platform import AsyncPlatform, SyncPlatform
from .serverless import AsyncServerless, SyncServerless


class SyncFriendli:
    def __init__(
        self,
        token: Optional[Union[Optional[str], Callable[[], Optional[str]]]] = None,
        server_idx: Optional[int] = None,
        server_url: Optional[str] = None,
        url_params: Optional[Dict[str, str]] = None,
        client: Optional[HttpClient] = None,
        async_client: Optional[AsyncHttpClient] = None,
        retry_config: OptionalNullable[RetryConfig] = UNSET,
        timeout_ms: Optional[int] = None,
        debug_logger: Optional[Logger] = None,
        core_cls: type[SyncFriendliCore] = SyncFriendliCore,
        config_cls: type[Config] = Config,
        *args,
        **kwargs,
    ):
        self._core = core_cls(
            token=token,
            server_idx=server_idx,
            server_url=server_url,
            url_params=url_params,
            client=client,
            async_client=async_client,
            retry_config=retry_config,
            timeout_ms=timeout_ms,
            debug_logger=debug_logger,
        )
        self._config = config_cls(*args, **kwargs)

        self.serverless = SyncServerless(core=self._core, config=self._config)
        self.dedicated = SyncDedicated(core=self._core, config=self._config)
        self.container = SyncContainer(core=self._core, config=self._config)
        self.platform = SyncPlatform(core=self._core, config=self._config)

    @property
    def core(self) -> SyncFriendliCore:
        return self._core

    @property
    def config(self) -> Config:
        return self._config

    def __enter__(self):
        self._core.__enter__()
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        self._core.__exit__(exc_type, exc_val, exc_tb)


class AsyncFriendli:
    def __init__(
        self,
        token: Optional[Union[Optional[str], Callable[[], Optional[str]]]] = None,
        server_idx: Optional[int] = None,
        server_url: Optional[str] = None,
        url_params: Optional[Dict[str, str]] = None,
        client: Optional[HttpClient] = None,
        async_client: Optional[AsyncHttpClient] = None,
        retry_config: OptionalNullable[RetryConfig] = UNSET,
        timeout_ms: Optional[int] = None,
        debug_logger: Optional[Logger] = None,
        core_cls: type[AsyncFriendliCore] = AsyncFriendliCore,
        config_cls: type[Config] = Config,
        *args,
        **kwargs,
    ):
        self._core = core_cls(
            token=token,
            server_idx=server_idx,
            server_url=server_url,
            url_params=url_params,
            client=client,
            async_client=async_client,
            retry_config=retry_config,
            timeout_ms=timeout_ms,
            debug_logger=debug_logger,
        )
        self._config = config_cls(*args, **kwargs)

        self.serverless = AsyncServerless(core=self._core, config=self._config)
        self.dedicated = AsyncDedicated(core=self._core, config=self._config)
        self.container = AsyncContainer(core=self._core, config=self._config)
        self.platform = AsyncPlatform(core=self._core, config=self._config)

    @property
    def core(self) -> AsyncFriendliCore:
        return self._core

    @property
    def config(self) -> Config:
        return self._config

    async def __aenter__(self):
        await self._core.__aenter__()
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        await self._core.__aexit__(exc_type, exc_val, exc_tb)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from abc import abstractmethod
from typing import Mapping, Optional, Union

from friendli_core import models, utils
from friendli_core._hooks import HookContext
from friendli_core.types import UNSET, OptionalNullable
from friendli_core.utils import eventstreaming, get_security_from_env

from .basesdk import AsyncSDK, BaseSDK, SyncSDK


class BaseCompletions(BaseSDK):
    pass


class SyncCompletions(BaseCompletions, SyncSDK):
    def complete(
        self,
        *,
        serverless_completions_body: Union[
            models.ServerlessCompletionsBody, models.ServerlessCompletionsBodyTypedDict
        ],
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ServerlessCompletionsSuccess:
        """Completions

        Generate text based on the given text prompt.

        :param serverless_completions_body:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms
        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        request = models.ServerlessCompletionsCompleteRequest(
            x_friendli_team=x_friendli_team,
            serverless_completions_body=utils.get_pydantic_model(
                serverless_completions_body, models.ServerlessCompletionsBody
            ),
        )
        req = self._build_request(
            method="POST",
            path="/serverless/v1/completions",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.serverless_completions_body,
                False,
                False,
                "json",
                models.ServerlessCompletionsBody,
            ),
            timeout_ms=timeout_ms,
        )
        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )
        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])
        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="serverlessCompletionsComplete",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(
                http_res.text, models.ServerlessCompletionsSuccess
            )
        if utils.match_response(http_res, ["422", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def stream(
        self,
        *,
        serverless_completions_stream_body: Union[
            models.ServerlessCompletionsStreamBody,
            models.ServerlessCompletionsStreamBodyTypedDict,
        ],
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> eventstreaming.EventStream[models.ServerlessCompletionsStreamSuccess]:
        """Stream completions

        Generate text based on the given text prompt.

        :param serverless_completions_stream_body:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms
        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        request = models.ServerlessCompletionsStreamRequest(
            x_friendli_team=x_friendli_team,
            serverless_completions_stream_body=utils.get_pydantic_model(
                serverless_completions_stream_body,
                models.ServerlessCompletionsStreamBody,
            ),
        )
        req = self._build_request(
            method="POST",
            path="/serverless/v1/completions#stream",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="text/event-stream",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.serverless_completions_stream_body,
                False,
                False,
                "json",
                models.ServerlessCompletionsStreamBody,
            ),
            timeout_ms=timeout_ms,
        )
        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )
        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])
        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="serverlessCompletionsStream",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            stream=True,
            retry_config=retry_config,
        )
        if utils.match_response(http_res, "200", "text/event-stream"):
            return eventstreaming.EventStream(
                http_res,
                lambda raw: utils.unmarshal_json(
                    raw, models.ServerlessCompletionsStreamSuccess
                ),
                sentinel="[DONE]",
            )
        if utils.match_response(http_res, ["422", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )


class AsyncCompletions(BaseCompletions, AsyncSDK):
    async def complete(
        self,
        *,
        serverless_completions_body: Union[
            models.ServerlessCompletionsBody, models.ServerlessCompletionsBodyTypedDict
        ],
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ServerlessCompletionsSuccess:
        """Completions

        Generate text based on the given text prompt.

        :param serverless_completions_body:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms
        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        request = models.ServerlessCompletionsCompleteRequest(
            x_friendli_team=x_friendli_team,
            serverless_completions_body=utils.get_pydantic_model(
                serverless_completions_body, models.ServerlessCompletionsBody
            ),
        )
        req = self._build_request(
            method="POST",
            path="/serverless/v1/completions",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.serverless_completions_body,
                False,
                False,
                "json",
                models.ServerlessCompletionsBody,
            ),
            timeout_ms=timeout_ms,
        )
        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )
        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])
        http_res = await self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="serverlessCompletionsComplete",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(
                http_res.text, models.ServerlessCompletionsSuccess
            )
        if utils.match_response(http_res, ["422", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def stream(
        self,
        *,
        serverless_completions_stream_body: Union[
            models.ServerlessCompletionsStreamBody,
            models.ServerlessCompletionsStreamBodyTypedDict,
        ],
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> eventstreaming.EventStreamAsync[models.ServerlessCompletionsStreamSuccess]:
        """Stream completions

        Generate text based on the given text prompt.

        :param serverless_completions_stream_body:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms
        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        request = models.ServerlessCompletionsStreamRequest(
            x_friendli_team=x_friendli_team,
            serverless_completions_stream_body=utils.get_pydantic_model(
                serverless_completions_stream_body,
                models.ServerlessCompletionsStreamBody,
            ),
        )
        req = self._build_request(
            method="POST",
            path="/serverless/v1/completions#stream",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="text/event-stream",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.serverless_completions_stream_body,
                False,
                False,
                "json",
                models.ServerlessCompletionsStreamBody,
            ),
            timeout_ms=timeout_ms,
        )
        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )
        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])
        http_res = await self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="serverlessCompletionsStream",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            stream=True,
            retry_config=retry_config,
        )
        if utils.match_response(http_res, "200", "text/event-stream"):
            return eventstreaming.EventStreamAsync(
                http_res,
                lambda raw: utils.unmarshal_json(
                    raw, models.ServerlessCompletionsStreamSuccess
                ),
                sentinel="[DONE]",
            )
        if utils.match_response(http_res, ["422", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



# Copyright (c) 2025-present, FriendliAI Inc. All rights reserved.

"""Friendli Python SDK."""

from __future__ import annotations

from typing import Any, Coroutine, Mapping, Optional, Union

from friendli_core import models, utils
from friendli_core.sdk import AsyncFriendliCore, SyncFriendliCore
from friendli_core.types import UNSET, OptionalNullable
from friendli_core.utils import eventstreaming

from ..config import Config


class SyncCompletions:
    def __init__(self, core: SyncFriendliCore, config: Config):
        self._core = core
        self._config = config

    def complete(
        self,
        *,
        dedicated_completions_body: Union[
            models.DedicatedCompletionsBody, models.DedicatedCompletionsBodyTypedDict
        ],
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DedicatedCompletionsSuccess:
        """Completions

        Generate text based on the given text prompt.

        :param dedicated_completions_body:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return self._core.dedicated.completions.complete(
            dedicated_completions_body=dedicated_completions_body,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )

    def stream(
        self,
        *,
        dedicated_completions_stream_body: Union[
            models.DedicatedCompletionsStreamBody,
            models.DedicatedCompletionsStreamBodyTypedDict,
        ],
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> eventstreaming.EventStream[models.DedicatedCompletionsStreamSuccess]:
        """Stream completions

        Generate text based on the given text prompt.

        :param dedicated_completions_stream_body:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return self._core.dedicated.completions.stream(
            dedicated_completions_stream_body=dedicated_completions_stream_body,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )


class AsyncCompletions:
    def __init__(self, core: AsyncFriendliCore, config: Config):
        self._core = core
        self._config = config

    async def complete(
        self,
        *,
        dedicated_completions_body: Union[
            models.DedicatedCompletionsBody, models.DedicatedCompletionsBodyTypedDict
        ],
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DedicatedCompletionsSuccess:
        """Completions

        Generate text based on the given text prompt.

        :param dedicated_completions_body:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return await self._core.dedicated.completions.complete(
            dedicated_completions_body=dedicated_completions_body,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )

    async def stream(
        self,
        *,
        dedicated_completions_stream_body: Union[
            models.DedicatedCompletionsStreamBody,
            models.DedicatedCompletionsStreamBodyTypedDict,
        ],
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> eventstreaming.EventStreamAsync[models.DedicatedCompletionsStreamSuccess]:
        """Stream completions

        Generate text based on the given text prompt.

        :param dedicated_completions_stream_body:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return await self._core.dedicated.completions.stream(
            dedicated_completions_stream_body=dedicated_completions_stream_body,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing_extensions import TypedDict

from friendli_core.types import BaseModel


class EndpointSimplescaleConfigTypedDict(TypedDict):
    r"""Simple scaling options."""

    replicas: int


class EndpointSimplescaleConfig(BaseModel):
    r"""Simple scaling options."""

    replicas: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

import pydantic
from pydantic.functional_validators import AfterValidator
from typing_extensions import Annotated, TypedDict

from friendli_core.types import BaseModel
from friendli_core.utils import validate_const

from .chatcompletebodytoolchoicefunction import (
    ChatCompleteBodyToolChoiceFunction,
    ChatCompleteBodyToolChoiceFunctionTypedDict,
)


class ChatCompleteBodyToolChoiceTypedDict(TypedDict):
    function: ChatCompleteBodyToolChoiceFunctionTypedDict
    type: Literal["function"]
    r"""The type of the tool. Currently, only `function` is supported."""


class ChatCompleteBodyToolChoice(BaseModel):
    function: ChatCompleteBodyToolChoiceFunction

    TYPE: Annotated[
        Annotated[Literal["function"], AfterValidator(validate_const("function"))],
        pydantic.Field(alias="type"),
    ] = "function"
    r"""The type of the tool. Currently, only `function` is supported."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict

from friendli_core.types import (
    UNSET,
    UNSET_SENTINEL,
    BaseModel,
    Nullable,
    OptionalNullable,
)

Order = Literal["asc", "desc"]
r"""Sort order by `created` timestamp. Use `asc` for ascending or `desc` for descending. Defaults to `desc`."""


class PlatformFilesListBodyTypedDict(TypedDict):
    after: NotRequired[Nullable[str]]
    r"""File ID after which to fetch the next page of results. Optional."""
    limit: NotRequired[Nullable[int]]
    r"""Maximum number of files to return, between [1, 10,000]. Defaults to 10,000."""
    order: NotRequired[Nullable[Order]]
    r"""Sort order by `created` timestamp. Use `asc` for ascending or `desc` for descending. Defaults to `desc`."""
    purpose: NotRequired[Nullable[str]]
    r"""Return files with the specified purpose. Optional."""


class PlatformFilesListBody(BaseModel):
    after: OptionalNullable[str] = UNSET
    r"""File ID after which to fetch the next page of results. Optional."""

    limit: OptionalNullable[int] = 10000
    r"""Maximum number of files to return, between [1, 10,000]. Defaults to 10,000."""

    order: OptionalNullable[Order] = "desc"
    r"""Sort order by `created` timestamp. Use `asc` for ascending or `desc` for descending. Defaults to `desc`."""

    purpose: OptionalNullable[str] = UNSET
    r"""Return files with the specified purpose. Optional."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["after", "limit", "order", "purpose"]
        nullable_fields = ["after", "limit", "order", "purpose"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

import io
from typing import IO, Literal, Optional, Union

import pydantic
from typing_extensions import Annotated, NotRequired, TypedDict

from friendli_core.types import BaseModel
from friendli_core.utils import FieldMetadata, MultipartFormMetadata


class FileTypedDict(TypedDict):
    file_name: str
    content: Union[bytes, IO[bytes], io.BufferedReader]
    content_type: NotRequired[str]


class File(BaseModel):
    file_name: Annotated[
        str, pydantic.Field(alias="fileName"), FieldMetadata(multipart=True)
    ]

    content: Annotated[
        Union[bytes, IO[bytes], io.BufferedReader],
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(content=True)),
    ]

    content_type: Annotated[
        Optional[str],
        pydantic.Field(alias="Content-Type"),
        FieldMetadata(multipart=True),
    ] = None


Purpose = Literal["batch", "model"]
r"""The intended purpose of the uploaded file. One of `batch` or `model`."""


class PlatformFilesUploadBodyTypedDict(TypedDict):
    file: FileTypedDict
    r"""The File object (not file name) to be uploaded."""
    purpose: Purpose
    r"""The intended purpose of the uploaded file. One of `batch` or `model`."""


class PlatformFilesUploadBody(BaseModel):
    file: Annotated[File, FieldMetadata(multipart=MultipartFormMetadata(file=True))]
    r"""The File object (not file name) to be uploaded."""

    purpose: Annotated[Purpose, FieldMetadata(multipart=True)]
    r"""The intended purpose of the uploaded file. One of `batch` or `model`."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from datetime import datetime
from typing import Literal

import pydantic
from pydantic import model_serializer
from typing_extensions import Annotated, NotRequired, TypedDict

from friendli_core.types import (
    UNSET,
    UNSET_SENTINEL,
    BaseModel,
    Nullable,
    OptionalNullable,
)

from .inferencedeploymenterrorcode import InferenceDeploymentErrorCode
from .inferencedeploymentstatus import InferenceDeploymentStatus

Phase = Literal[
    "REQUESTING_VIRTUAL_MACHINE", "DOWNLOADING_MODEL", "ENGINE_INITIALIZING"
]
r"""The current phase of the endpoint."""


class DedicatedEndpointStatusTypedDict(TypedDict):
    r"""Dedicated endpoint status."""

    created_at: datetime
    r"""When the endpoint was created."""
    status: InferenceDeploymentStatus
    r"""Status of inference deployment."""
    error_code: NotRequired[Nullable[InferenceDeploymentErrorCode]]
    r"""Error code if deployment failed."""
    phase: NotRequired[Nullable[Phase]]
    r"""The current phase of the endpoint."""
    updated_at: NotRequired[Nullable[datetime]]
    r"""When the endpoint was last updated."""


class DedicatedEndpointStatus(BaseModel):
    r"""Dedicated endpoint status."""

    created_at: Annotated[datetime, pydantic.Field(alias="createdAt")]
    r"""When the endpoint was created."""

    status: InferenceDeploymentStatus
    r"""Status of inference deployment."""

    error_code: Annotated[
        OptionalNullable[InferenceDeploymentErrorCode],
        pydantic.Field(alias="errorCode"),
    ] = UNSET
    r"""Error code if deployment failed."""

    phase: OptionalNullable[Phase] = UNSET
    r"""The current phase of the endpoint."""

    updated_at: Annotated[
        OptionalNullable[datetime], pydantic.Field(alias="updatedAt")
    ] = UNSET
    r"""When the endpoint was last updated."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["errorCode", "phase", "updatedAt"]
        nullable_fields = ["errorCode", "phase", "updatedAt"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



# Copyright (c) 2025-present, FriendliAI Inc. All rights reserved.

"""Friendli Python SDK."""

from __future__ import annotations

from typing import Any, Coroutine, List, Mapping, Optional

from friendli_core import models, utils
from friendli_core.sdk import AsyncFriendliCore, SyncFriendliCore
from friendli_core.types import UNSET, OptionalNullable

from ..config import Config


class SyncToken:
    def __init__(self, core: SyncFriendliCore, config: Config):
        self._core = core
        self._config = config

    def tokenization(
        self,
        *,
        model: str,
        prompt: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DedicatedTokenizationSuccess:
        """Tokenization

        By giving a text input, generate a tokenized output of token IDs.

        :param model: ID of target endpoint. If you want to send request to specific adapter, use the format \\"YOUR_ENDPOINT_ID:YOUR_ADAPTER_ROUTE\\". Otherwise, you can just use \\"YOUR_ENDPOINT_ID\\" alone.
        :param prompt: Input text prompt to tokenize.
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return self._core.dedicated.token.tokenization(
            model=model,
            prompt=prompt,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )

    def detokenization(
        self,
        *,
        model: str,
        tokens: List[int],
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DedicatedDetokenizationSuccess:
        """Detokenization

        By giving a list of tokens, generate a detokenized output text string.

        :param model: ID of target endpoint. If you want to send request to specific adapter, use the format \\"YOUR_ENDPOINT_ID:YOUR_ADAPTER_ROUTE\\". Otherwise, you can just use \\"YOUR_ENDPOINT_ID\\" alone.
        :param tokens: A token sequence to detokenize.
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return self._core.dedicated.token.detokenization(
            model=model,
            tokens=tokens,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )


class AsyncToken:
    def __init__(self, core: AsyncFriendliCore, config: Config):
        self._core = core
        self._config = config

    async def tokenization(
        self,
        *,
        model: str,
        prompt: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DedicatedTokenizationSuccess:
        """Tokenization

        By giving a text input, generate a tokenized output of token IDs.

        :param model: ID of target endpoint. If you want to send request to specific adapter, use the format \\"YOUR_ENDPOINT_ID:YOUR_ADAPTER_ROUTE\\". Otherwise, you can just use \\"YOUR_ENDPOINT_ID\\" alone.
        :param prompt: Input text prompt to tokenize.
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return await self._core.dedicated.token.tokenization(
            model=model,
            prompt=prompt,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )

    async def detokenization(
        self,
        *,
        model: str,
        tokens: List[int],
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DedicatedDetokenizationSuccess:
        """Detokenization

        By giving a list of tokens, generate a detokenized output text string.

        :param model: ID of target endpoint. If you want to send request to specific adapter, use the format \\"YOUR_ENDPOINT_ID:YOUR_ADAPTER_ROUTE\\". Otherwise, you can just use \\"YOUR_ENDPOINT_ID\\" alone.
        :param tokens: A token sequence to detokenize.
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return await self._core.dedicated.token.detokenization(
            model=model,
            tokens=tokens,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )



# Copyright (c) 2025-present, FriendliAI Inc. All rights reserved.

"""Friendli Python SDK."""

from __future__ import annotations

from typing import Any, Coroutine, Mapping, Optional, Union

import httpx

from friendli_core import models, utils
from friendli_core.sdk import AsyncFriendliCore, SyncFriendliCore
from friendli_core.types import UNSET, OptionalNullable

from ..config import Config


class SyncFiles:
    def __init__(self, core: SyncFriendliCore, config: Config):
        self._core = core
        self._config = config

    def upload(
        self,
        *,
        file: Union[models.File, models.FileTypedDict],
        purpose: models.Purpose,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesUploadResult:
        """Files upload

        Uploads a file.

        :param file: The File object (not file name) to be uploaded.
        :param purpose: The intended purpose of the uploaded file. One of `batch` or `model`.
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return self._core.platform.files.upload(
            file=file,
            purpose=purpose,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )

    def list(
        self,
        *,
        x_friendli_team: OptionalNullable[str] = UNSET,
        after: OptionalNullable[str] = UNSET,
        limit: OptionalNullable[int] = 10000,
        order: OptionalNullable[models.Order] = "desc",
        purpose: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesListResult:
        """Files list

        List files.

        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param after: File ID after which to fetch the next page of results. Optional.
        :param limit: Maximum number of files to return, between [1, 10,000]. Defaults to 10,000.
        :param order: Sort order by `created` timestamp. Use `asc` for ascending or `desc` for descending. Defaults to `desc`.
        :param purpose: Return files with the specified purpose. Optional.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return self._core.platform.files.list(
            x_friendli_team=x_friendli_team,
            after=after,
            limit=limit,
            order=order,
            purpose=purpose,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )

    def retrieve(
        self,
        *,
        file_id: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesRetrieveResult:
        """File retrieve

        Retrieves a file info.

        :param file_id:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return self._core.platform.files.retrieve(
            file_id=file_id,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )

    def delete(
        self,
        *,
        file_id: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesDeleteResult:
        """Files delete

        Deletes a file.

        :param file_id:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return self._core.platform.files.delete(
            file_id=file_id,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )

    def download(
        self,
        *,
        file_id: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> httpx.Response:
        """Files download

        Downloads a file.

        :param file_id:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return self._core.platform.files.download(
            file_id=file_id,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )


class AsyncFiles:
    def __init__(self, core: AsyncFriendliCore, config: Config):
        self._core = core
        self._config = config

    async def upload(
        self,
        *,
        file: Union[models.File, models.FileTypedDict],
        purpose: models.Purpose,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesUploadResult:
        """Files upload

        Uploads a file.

        :param file: The File object (not file name) to be uploaded.
        :param purpose: The intended purpose of the uploaded file. One of `batch` or `model`.
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return await self._core.platform.files.upload(
            file=file,
            purpose=purpose,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )

    async def list(
        self,
        *,
        x_friendli_team: OptionalNullable[str] = UNSET,
        after: OptionalNullable[str] = UNSET,
        limit: OptionalNullable[int] = 10000,
        order: OptionalNullable[models.Order] = "desc",
        purpose: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesListResult:
        """Files list

        List files.

        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param after: File ID after which to fetch the next page of results. Optional.
        :param limit: Maximum number of files to return, between [1, 10,000]. Defaults to 10,000.
        :param order: Sort order by `created` timestamp. Use `asc` for ascending or `desc` for descending. Defaults to `desc`.
        :param purpose: Return files with the specified purpose. Optional.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return await self._core.platform.files.list(
            x_friendli_team=x_friendli_team,
            after=after,
            limit=limit,
            order=order,
            purpose=purpose,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )

    async def retrieve(
        self,
        *,
        file_id: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesRetrieveResult:
        """File retrieve

        Retrieves a file info.

        :param file_id:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return await self._core.platform.files.retrieve(
            file_id=file_id,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )

    async def delete(
        self,
        *,
        file_id: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesDeleteResult:
        """Files delete

        Deletes a file.

        :param file_id:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return await self._core.platform.files.delete(
            file_id=file_id,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )

    async def download(
        self,
        *,
        file_id: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> httpx.Response:
        """Files download

        Downloads a file.

        :param file_id:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        return await self._core.platform.files.download(
            file_id=file_id,
            x_friendli_team=x_friendli_team,
            retries=retries,
            server_url=server_url,
            timeout_ms=timeout_ms,
            http_headers=http_headers,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

InferenceDeploymentErrorCode = Literal[
    "WORKLOAD_INIT_UNKNOWN_ERROR",
    "WORKLOAD_INIT_SETTINGS_ERROR",
    "WORKLOAD_INIT_GRPC_ERROR",
    "WORKLOAD_INIT_MANIFEST_NOT_FOUND_ERROR",
    "WORKLOAD_INIT_MANIFEST_TYPE_ERROR",
    "WORKLOAD_INIT_DOWNLOAD_ERROR",
    "WORKLOAD_INIT_INVALID_TOKEN_ERROR",
    "WORKLOAD_INIT_CANNOT_ACCESS_REPO_ERROR",
    "WORKLOAD_INIT_HF_WANDB_API_ERROR",
    "WORKLOAD_INIT_INSUFFICIENT_DISK_ERROR",
    "INFERENCE_ENGINE_UNKNOWN_ERROR",
    "INFERENCE_ENGINE_INVALID_ARGUMENT_ERROR",
    "INFERENCE_ENGINE_MEMORY_ERROR",
    "INFERENCE_ENGINE_METERING_CLIENT_CONFIG_ERROR",
]
r"""ErrorCode type."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

from typing_extensions import TypedDict

from friendli_core.types import BaseModel

URLImageItemResponseFormat = Literal["url", "raw", "png", "jpeg", "jpg"]
r"""The format of the generated image. One of `url(default)`, `raw`, `png`, `jpeg`, and `jpg`."""


class URLImageItemTypedDict(TypedDict):
    response_format: URLImageItemResponseFormat
    r"""The format of the generated image. One of `url(default)`, `raw`, `png`, `jpeg`, and `jpg`."""
    seed: int
    r"""The seed used during image generation."""
    url: str
    r"""The URL of the generated image."""


class URLImageItem(BaseModel):
    response_format: URLImageItemResponseFormat
    r"""The format of the generated image. One of `url(default)`, `raw`, `png`, `jpeg`, and `jpg`."""

    seed: int
    r"""The seed used during image generation."""

    url: str
    r"""The URL of the generated image."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import List

from typing_extensions import TypedDict

from friendli_core.types import BaseModel

from .fileobject import FileObject, FileObjectTypedDict


class PlatformFilesListResultTypedDict(TypedDict):
    data: List[FileObjectTypedDict]


class PlatformFilesListResult(BaseModel):
    data: List[FileObject]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Union

from typing_extensions import TypeAliasType

from .completionsstreamdedicatedbodywithprompt import (
    CompletionsStreamDedicatedBodyWithPrompt,
    CompletionsStreamDedicatedBodyWithPromptTypedDict,
)
from .completionsstreamdedicatedbodywithtokens import (
    CompletionsStreamDedicatedBodyWithTokens,
    CompletionsStreamDedicatedBodyWithTokensTypedDict,
)

DedicatedCompletionsStreamBodyTypedDict = TypeAliasType(
    "DedicatedCompletionsStreamBodyTypedDict",
    Union[
        CompletionsStreamDedicatedBodyWithPromptTypedDict,
        CompletionsStreamDedicatedBodyWithTokensTypedDict,
    ],
)


DedicatedCompletionsStreamBody = TypeAliasType(
    "DedicatedCompletionsStreamBody",
    Union[
        CompletionsStreamDedicatedBodyWithPrompt,
        CompletionsStreamDedicatedBodyWithTokens,
    ],
)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Optional

from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict

from friendli_core.types import (
    UNSET,
    UNSET_SENTINEL,
    BaseModel,
    Nullable,
    OptionalNullable,
)


class EndpointAdvancedConfigTypedDict(TypedDict):
    r"""Endpoint advanced config."""

    tokenizer_add_special_tokens: bool
    tokenizer_skip_special_tokens: bool
    enable_content_logging: NotRequired[Nullable[bool]]
    max_batch_size: NotRequired[int]
    max_input_length: NotRequired[Nullable[int]]
    max_token_count: NotRequired[int]


class EndpointAdvancedConfig(BaseModel):
    r"""Endpoint advanced config."""

    tokenizer_add_special_tokens: bool

    tokenizer_skip_special_tokens: bool

    enable_content_logging: OptionalNullable[bool] = UNSET

    max_batch_size: Optional[int] = 256

    max_input_length: OptionalNullable[int] = UNSET

    max_token_count: Optional[int] = 2560

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "enable_content_logging",
            "max_batch_size",
            "max_input_length",
            "max_token_count",
        ]
        nullable_fields = ["enable_content_logging", "max_input_length"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from abc import abstractmethod

from friendli_core.files import AsyncFiles, SyncFiles

from .basesdk import AsyncSDK, BaseSDK, SyncSDK
from .sdkconfiguration import SDKConfiguration


class BasePlatform(BaseSDK):
    def __init__(self, sdk_config: SDKConfiguration) -> None:
        BaseSDK.__init__(self, sdk_config)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    @abstractmethod
    def _init_sdks(self):
        pass


class SyncPlatform(BasePlatform, SyncSDK):
    files: SyncFiles

    def _init_sdks(self):
        self.files = SyncFiles(self.sdk_configuration)


class AsyncPlatform(BasePlatform, AsyncSDK):
    files: AsyncFiles

    def _init_sdks(self):
        self.files = AsyncFiles(self.sdk_configuration)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from abc import abstractmethod

from friendli_core.chat import AsyncChat, SyncChat
from friendli_core.completions import AsyncCompletions, SyncCompletions
from friendli_core.knowledge import AsyncKnowledge, SyncKnowledge
from friendli_core.model import AsyncModel, SyncModel
from friendli_core.token import AsyncToken, SyncToken
from friendli_core.toolassistedchat import AsyncToolAssistedChat, SyncToolAssistedChat

from .basesdk import AsyncSDK, BaseSDK, SyncSDK
from .sdkconfiguration import SDKConfiguration


class BaseServerless(BaseSDK):
    def __init__(self, sdk_config: SDKConfiguration) -> None:
        BaseSDK.__init__(self, sdk_config)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    @abstractmethod
    def _init_sdks(self):
        pass


class SyncServerless(BaseServerless, SyncSDK):
    chat: SyncChat
    completions: SyncCompletions
    token: SyncToken
    knowledge: SyncKnowledge
    model: SyncModel
    tool_assisted_chat: SyncToolAssistedChat

    def _init_sdks(self):
        self.chat = SyncChat(self.sdk_configuration)
        self.completions = SyncCompletions(self.sdk_configuration)
        self.token = SyncToken(self.sdk_configuration)
        self.knowledge = SyncKnowledge(self.sdk_configuration)
        self.model = SyncModel(self.sdk_configuration)
        self.tool_assisted_chat = SyncToolAssistedChat(self.sdk_configuration)


class AsyncServerless(BaseServerless, AsyncSDK):
    chat: AsyncChat
    completions: AsyncCompletions
    token: AsyncToken
    knowledge: AsyncKnowledge
    model: AsyncModel
    tool_assisted_chat: AsyncToolAssistedChat

    def _init_sdks(self):
        self.chat = AsyncChat(self.sdk_configuration)
        self.completions = AsyncCompletions(self.sdk_configuration)
        self.token = AsyncToken(self.sdk_configuration)
        self.knowledge = AsyncKnowledge(self.sdk_configuration)
        self.model = AsyncModel(self.sdk_configuration)
        self.tool_assisted_chat = AsyncToolAssistedChat(self.sdk_configuration)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

import pydantic
from pydantic.functional_validators import AfterValidator
from typing_extensions import Annotated, TypedDict

from friendli_core.types import BaseModel
from friendli_core.utils import validate_const


class PlatformFilesDeleteResultTypedDict(TypedDict):
    deleted: bool
    r"""Deletion status. `true` if deleted, otherwise `false`."""
    id: str
    r"""ID of the file of interest."""
    object: Literal["file"]
    r"""The object type, which is always `file`."""


class PlatformFilesDeleteResult(BaseModel):
    deleted: bool
    r"""Deletion status. `true` if deleted, otherwise `false`."""

    id: str
    r"""ID of the file of interest."""

    OBJECT: Annotated[
        Annotated[Literal["file"], AfterValidator(validate_const("file"))],
        pydantic.Field(alias="object"),
    ] = "file"
    r"""The object type, which is always `file`."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Union

from typing_extensions import TypeAliasType

from .completionsserverlessbodywithprompt import (
    CompletionsServerlessBodyWithPrompt,
    CompletionsServerlessBodyWithPromptTypedDict,
)
from .completionsserverlessbodywithtokens import (
    CompletionsServerlessBodyWithTokens,
    CompletionsServerlessBodyWithTokensTypedDict,
)

ServerlessCompletionsBodyTypedDict = TypeAliasType(
    "ServerlessCompletionsBodyTypedDict",
    Union[
        CompletionsServerlessBodyWithPromptTypedDict,
        CompletionsServerlessBodyWithTokensTypedDict,
    ],
)


ServerlessCompletionsBody = TypeAliasType(
    "ServerlessCompletionsBody",
    Union[CompletionsServerlessBodyWithPrompt, CompletionsServerlessBodyWithTokens],
)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from abc import abstractmethod
from typing import Mapping, Optional, Union

import httpx

from friendli_core import models, utils
from friendli_core._hooks import HookContext
from friendli_core.types import UNSET, OptionalNullable
from friendli_core.utils import get_security_from_env

from .basesdk import AsyncSDK, BaseSDK, SyncSDK


class BaseFiles(BaseSDK):
    pass


class SyncFiles(BaseFiles, SyncSDK):
    def upload(
        self,
        *,
        file: Union[models.File, models.FileTypedDict],
        purpose: models.Purpose,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesUploadResult:
        """Files upload

        Uploads a file.

        :param file: The File object (not file name) to be uploaded.
        :param purpose: The intended purpose of the uploaded file. One of `batch` or `model`.
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms
        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        request = models.PlatformFilesUploadRequest(
            x_friendli_team=x_friendli_team,
            platform_files_upload_body=models.PlatformFilesUploadBody(
                file=utils.get_pydantic_model(file, models.File), purpose=purpose
            ),
        )
        req = self._build_request(
            method="POST",
            path="/platform/v1/files",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.platform_files_upload_body,
                False,
                False,
                "multipart",
                models.PlatformFilesUploadBody,
            ),
            timeout_ms=timeout_ms,
        )
        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )
        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])
        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="platformFilesUpload",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.PlatformFilesUploadResult)
        if utils.match_response(http_res, ["400", "422", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def list(
        self,
        *,
        x_friendli_team: OptionalNullable[str] = UNSET,
        after: OptionalNullable[str] = UNSET,
        limit: OptionalNullable[int] = 10000,
        order: OptionalNullable[models.Order] = "desc",
        purpose: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesListResult:
        """Files list

        List files.

        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param after: File ID after which to fetch the next page of results. Optional.
        :param limit: Maximum number of files to return, between [1, 10,000]. Defaults to 10,000.
        :param order: Sort order by `created` timestamp. Use `asc` for ascending or `desc` for descending. Defaults to `desc`.
        :param purpose: Return files with the specified purpose. Optional.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms
        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        request = models.PlatformFilesListRequest(
            x_friendli_team=x_friendli_team,
            platform_files_list_body=models.PlatformFilesListBody(
                after=after, limit=limit, order=order, purpose=purpose
            ),
        )
        req = self._build_request(
            method="GET",
            path="/platform/v1/files",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.platform_files_list_body,
                False,
                False,
                "json",
                models.PlatformFilesListBody,
            ),
            timeout_ms=timeout_ms,
        )
        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )
        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])
        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="platformFilesList",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.PlatformFilesListResult)
        if utils.match_response(http_res, ["400", "422", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def retrieve(
        self,
        *,
        file_id: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesRetrieveResult:
        """File retrieve

        Retrieves a file info.

        :param file_id:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms
        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        request = models.PlatformFilesRetrieveRequest(
            file_id=file_id, x_friendli_team=x_friendli_team
        )
        req = self._build_request(
            method="GET",
            path="/platform/v1/files/{file_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )
        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )
        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])
        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="platformFilesRetrieve",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(
                http_res.text, models.PlatformFilesRetrieveResult
            )
        if utils.match_response(http_res, ["400", "422", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def delete(
        self,
        *,
        file_id: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesDeleteResult:
        """Files delete

        Deletes a file.

        :param file_id:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms
        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        request = models.PlatformFilesDeleteRequest(
            file_id=file_id, x_friendli_team=x_friendli_team
        )
        req = self._build_request(
            method="DELETE",
            path="/platform/v1/files/{file_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )
        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )
        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])
        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="platformFilesDelete",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.PlatformFilesDeleteResult)
        if utils.match_response(http_res, ["400", "422", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def download(
        self,
        *,
        file_id: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> httpx.Response:
        """Files download

        Downloads a file.

        :param file_id:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms
        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        request = models.PlatformFilesDownloadRequest(
            file_id=file_id, x_friendli_team=x_friendli_team
        )
        req = self._build_request(
            method="GET",
            path="/platform/v1/files/{file_id}/download",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/octet-stream",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )
        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )
        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])
        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="platformFilesDownload",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "422", "4XX", "5XX"],
            stream=True,
            retry_config=retry_config,
        )
        if utils.match_response(http_res, "200", "application/octet-stream"):
            return http_res
        if utils.match_response(http_res, ["400", "422", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )


class AsyncFiles(BaseFiles, AsyncSDK):
    async def upload(
        self,
        *,
        file: Union[models.File, models.FileTypedDict],
        purpose: models.Purpose,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesUploadResult:
        """Files upload

        Uploads a file.

        :param file: The File object (not file name) to be uploaded.
        :param purpose: The intended purpose of the uploaded file. One of `batch` or `model`.
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms
        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        request = models.PlatformFilesUploadRequest(
            x_friendli_team=x_friendli_team,
            platform_files_upload_body=models.PlatformFilesUploadBody(
                file=utils.get_pydantic_model(file, models.File), purpose=purpose
            ),
        )
        req = self._build_request(
            method="POST",
            path="/platform/v1/files",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.platform_files_upload_body,
                False,
                False,
                "multipart",
                models.PlatformFilesUploadBody,
            ),
            timeout_ms=timeout_ms,
        )
        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )
        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])
        http_res = await self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="platformFilesUpload",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.PlatformFilesUploadResult)
        if utils.match_response(http_res, ["400", "422", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def list(
        self,
        *,
        x_friendli_team: OptionalNullable[str] = UNSET,
        after: OptionalNullable[str] = UNSET,
        limit: OptionalNullable[int] = 10000,
        order: OptionalNullable[models.Order] = "desc",
        purpose: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesListResult:
        """Files list

        List files.

        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param after: File ID after which to fetch the next page of results. Optional.
        :param limit: Maximum number of files to return, between [1, 10,000]. Defaults to 10,000.
        :param order: Sort order by `created` timestamp. Use `asc` for ascending or `desc` for descending. Defaults to `desc`.
        :param purpose: Return files with the specified purpose. Optional.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms
        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        request = models.PlatformFilesListRequest(
            x_friendli_team=x_friendli_team,
            platform_files_list_body=models.PlatformFilesListBody(
                after=after, limit=limit, order=order, purpose=purpose
            ),
        )
        req = self._build_request(
            method="GET",
            path="/platform/v1/files",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.platform_files_list_body,
                False,
                False,
                "json",
                models.PlatformFilesListBody,
            ),
            timeout_ms=timeout_ms,
        )
        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )
        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])
        http_res = await self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="platformFilesList",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.PlatformFilesListResult)
        if utils.match_response(http_res, ["400", "422", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def retrieve(
        self,
        *,
        file_id: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesRetrieveResult:
        """File retrieve

        Retrieves a file info.

        :param file_id:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms
        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        request = models.PlatformFilesRetrieveRequest(
            file_id=file_id, x_friendli_team=x_friendli_team
        )
        req = self._build_request(
            method="GET",
            path="/platform/v1/files/{file_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )
        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )
        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])
        http_res = await self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="platformFilesRetrieve",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(
                http_res.text, models.PlatformFilesRetrieveResult
            )
        if utils.match_response(http_res, ["400", "422", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def delete(
        self,
        *,
        file_id: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PlatformFilesDeleteResult:
        """Files delete

        Deletes a file.

        :param file_id:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms
        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        request = models.PlatformFilesDeleteRequest(
            file_id=file_id, x_friendli_team=x_friendli_team
        )
        req = self._build_request(
            method="DELETE",
            path="/platform/v1/files/{file_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )
        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )
        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])
        http_res = await self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="platformFilesDelete",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.PlatformFilesDeleteResult)
        if utils.match_response(http_res, ["400", "422", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def download(
        self,
        *,
        file_id: str,
        x_friendli_team: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> httpx.Response:
        """Files download

        Downloads a file.

        :param file_id:
        :param x_friendli_team: ID of team to run requests as (optional parameter).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms
        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        request = models.PlatformFilesDownloadRequest(
            file_id=file_id, x_friendli_team=x_friendli_team
        )
        req = self._build_request(
            method="GET",
            path="/platform/v1/files/{file_id}/download",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/octet-stream",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )
        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )
        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])
        http_res = await self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="platformFilesDownload",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "422", "4XX", "5XX"],
            stream=True,
            retry_config=retry_config,
        )
        if utils.match_response(http_res, "200", "application/octet-stream"):
            return http_res
        if utils.match_response(http_res, ["400", "422", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



# Copyright (c) 2025-present, FriendliAI Inc. All rights reserved.

"""Friendli Python SDK."""

from __future__ import annotations

from friendli_core.sdk import AsyncFriendliCore, SyncFriendliCore

from ..config import Config
from .chat import AsyncChat, SyncChat
from .completions import AsyncCompletions, SyncCompletions
from .knowledge import AsyncKnowledge, SyncKnowledge
from .model import AsyncModel, SyncModel
from .token import AsyncToken, SyncToken
from .tool_assisted_chat import AsyncToolAssistedChat, SyncToolAssistedChat


class SyncServerless:
    def __init__(self, core: SyncFriendliCore, config: Config):
        self._core = core
        self._config = config

        self.chat = SyncChat(core=self._core, config=self._config)
        self.completions = SyncCompletions(core=self._core, config=self._config)
        self.token = SyncToken(core=self._core, config=self._config)
        self.knowledge = SyncKnowledge(core=self._core, config=self._config)
        self.model = SyncModel(core=self._core, config=self._config)
        self.tool_assisted_chat = SyncToolAssistedChat(
            core=self._core, config=self._config
        )


class AsyncServerless:
    def __init__(self, core: AsyncFriendliCore, config: Config):
        self._core = core
        self._config = config

        self.chat = AsyncChat(core=self._core, config=self._config)
        self.completions = AsyncCompletions(core=self._core, config=self._config)
        self.token = AsyncToken(core=self._core, config=self._config)
        self.knowledge = AsyncKnowledge(core=self._core, config=self._config)
        self.model = AsyncModel(core=self._core, config=self._config)
        self.tool_assisted_chat = AsyncToolAssistedChat(
            core=self._core, config=self._config
        )



# Copyright (c) 2025-present, FriendliAI Inc. All rights reserved.

"""Friendli Python SDK."""

from __future__ import annotations

from friendli_core.sdk import AsyncFriendliCore, SyncFriendliCore

from ..config import Config
from .chat import AsyncChat, SyncChat
from .completions import AsyncCompletions, SyncCompletions
from .token import AsyncToken, SyncToken


class SyncContainer:
    def __init__(self, core: SyncFriendliCore, config: Config):
        self._core = core
        self._config = config

        self.chat = SyncChat(core=self._core, config=self._config)
        self.completions = SyncCompletions(core=self._core, config=self._config)
        self.token = SyncToken(core=self._core, config=self._config)


class AsyncContainer:
    def __init__(self, core: AsyncFriendliCore, config: Config):
        self._core = core
        self._config = config

        self.chat = AsyncChat(core=self._core, config=self._config)
        self.completions = AsyncCompletions(core=self._core, config=self._config)
        self.token = AsyncToken(core=self._core, config=self._config)



# Copyright (c) 2025-present, FriendliAI Inc. All rights reserved.

"""Friendli Python SDK."""

from __future__ import annotations

from friendli_core.httpclient import HttpClient, AsyncHttpClient, ClientOwner, close_clients
